==> commerce_novaposhta-2.0.0-rc1.tar.gz: commerce_novaposhta/tests/src/Kernel/NovaposhtaItemTest.php <==
<?php

namespace Drupal\Tests\commerce_novaposhta\Kernel;

use Drupal\entity_test\Entity\EntityTest;
use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\KernelTests\Core\Entity\EntityKernelTestBase;

/**
 * Class NovaposhtaItemTest.
 *
 * @package Drupal\Tests\commerce_novaposhta\Kernel
 *
 * @group commerce_novaposhta
 */
class NovaposhtaItemTest extends EntityKernelTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = [
    'commerce_novaposhta',
  ];

  /**
   * The test entity.
   *
   * @var \Drupal\entity_test\Entity\EntityTest
   */
  protected $testEntity;

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  protected function setUp() {
    parent::setUp();

    $field_storage = FieldStorageConfig::create([
      'field_name' => 'field_novaposhta',
      'entity_type' => 'entity_test',
      'type' => 'novaposhta',
      'cardinality' => 1,
    ]);
    $field_storage->save();

    $field = FieldConfig::create([
      'field_name' => 'field_novaposhta',
      'entity_type' => 'entity_test',
      'bundle' => 'entity_test',
    ]);
    $field->save();

    $entity = EntityTest::create([
      'name' => 'Test',
    ]);
    $entity->save();
    $this->testEntity = $entity;
  }

  /**
   * Test field item.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function testNovaposhta() {
    $field_data = [
      'city' => 'Lviv',
      'warehouse' => 'underground_metro',
      'city_data' => [],
      'warehouse_data' => [],
    ];
    $this->testEntity->set('field_novaposhta', $field_data);
    $this->testEntity->save();

    $this->testEntity = $this->reloadEntity($this->testEntity);
    $stored_value = $this->testEntity->get('field_novaposhta')->getValue();
    $this->assertEqual($field_data, $stored_value[0]);
  }

}

==> commerce_novaposhta-2.0.2.tar.gz: commerce_novaposhta/tests/src/Kernel/NovaposhtaItemTest.php <==
<?php

namespace Drupal\Tests\commerce_novaposhta\Kernel;

use Drupal\entity_test\Entity\EntityTest;
use Drupal\field\Entity\FieldConfig;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\KernelTests\Core\Entity\EntityKernelTestBase;

/**
 * Class NovaposhtaItemTest.
 *
 * @package Drupal\Tests\commerce_novaposhta\Kernel
 *
 * @group commerce_novaposhta
 */
class NovaposhtaItemTest extends EntityKernelTestBase {

  /**
   * Modules to enable.
   *
   * @var array
   */
  protected static $modules = [
    'commerce_novaposhta',
  ];

  /**
   * The test entity.
   *
   * @var \Drupal\entity_test\Entity\EntityTest
   */
  protected $testEntity;

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  protected function setUp(): void {
    parent::setUp();

    $field_storage = FieldStorageConfig::create([
      'field_name' => 'field_novaposhta',
      'entity_type' => 'entity_test',
      'type' => 'novaposhta',
      'cardinality' => 1,
    ]);
    $field_storage->save();

    $field = FieldConfig::create([
      'field_name' => 'field_novaposhta',
      'entity_type' => 'entity_test',
      'bundle' => 'entity_test',
    ]);
    $field->save();

    $entity = EntityTest::create([
      'name' => 'Test',
    ]);
    $entity->save();
    $this->testEntity = $entity;
  }

  /**
   * Test field item.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function testNovaposhta() {
    $field_data = [
      'city' => 'Lviv',
      'warehouse' => 'underground_metro',
      'city_data' => [],
      'warehouse_data' => [],
    ];
    $this->testEntity->set('field_novaposhta', $field_data);
    $this->testEntity->save();

    $this->testEntity = $this->reloadEntity($this->testEntity);
    $stored_value = $this->testEntity->get('field_novaposhta')->getValue();
    $this->assertEquals($stored_value[0], $field_data);
  }

}
